@@ -704,7 +704,12 @@ class LaharFlowData(object):
         if fileext=='.txt':
             return self._get_data_txt(LaharFlowFile)
         elif fileext=='.nc':
-            return self._get_data_nc(LaharFlowFile)
+            try:
+                d = self._get_data_nc(LaharFlowFile)
+            except:
+                print('Could not load netcdf file '+LaharFlowFile)
+                d = None
+            return d
         else:
             raise ValueError('File {} not recognized'.format(LaharFlowFile))
         
@@ -720,6 +725,8 @@ class LaharFlowData(object):
         # cols = csv_active_cols(LaharFlowFile)
         # data = np.genfromtxt(LaharFlowFile, delimiter=',', names=True, usecols=cols)
         data = self._get_data(filename)
+        print(filename)
+        print(data)
         
         extra_cols = ['tile', 'x_distance', 'y_distance', 'latitude', 'longitude']
         if var is None:
@@ -953,6 +960,8 @@ class LaharFlowData(object):
     def _get_max_bed_evolution(self):
         last_outfile = int(self.get_snapshot_files()[-1])
 
+        print(last_outfile)
+
         data = self.raster(last_outfile, var=['elevation_change'])
 
         bt = data['elevation_change'].values
@@ -986,7 +995,10 @@ class LaharFlowData(object):
         
         if 'Maximums.nc' in self.nc_files:
             d = self._get_data('Maximums.nc')
-            self.MaxDepth = d['maximum_depth'].max()
+            if d is not None:
+                self.MaxDepth = d['maximum_depth'].max()
+            else:
+                self.MaxDepth = None
             return
         elif 'MaxHeights.txt' in self.txt_files:
             _, _, h = self._get_data_column('MaxHeights.txt', 5)
@@ -1019,7 +1031,10 @@ class LaharFlowData(object):
         
         if 'Maximums.nc' in self.nc_files:
             d = self._get_data('Maximums.nc')
-            self.MaxSpeed = d['maximum_speed'].max()
+            if d is not None:
+                self.MaxSpeed = d['maximum_speed'].max()
+            else:
+                self.MaxSpeed = None
             return
         elif 'MaxSpeeds.txt' in self.txt_files:
             _, _, spd = self._get_data_column('MaxSpeeds.txt', 5)
